@@ -56,6 +56,11 @@
 BIO_METHOD *BIO_s_file();
 #endif
 
+#ifdef WIN32
+#define rename(from,to) WIN32_rename((from),(to))
+int WIN32_rename(char *oldname,char *newname);
+#endif
+
 #ifndef MONOLITH
 
 #define MAIN(a,v)	main(a,v)
