@@ -492,7 +492,7 @@ bad:
 				((*p >= 'A') && (*p <= 'F')) ||
 				((*p >= 'a') && (*p <= 'f')))  )
 				{
-				fprintf(stderr,"entry %d: bad serial number characters, char pos %d, char is '%c'\n",i+1,p-pp[DB_serial],*p);
+				fprintf(stderr,"entry %d: bad serial number characters, char pos %ld, char is '%c'\n",i+1,(long)(p-pp[DB_serial]),*p);
 				goto err;
 				}
 			p++;
@@ -723,6 +723,10 @@ bad:
 			/* Rename the database and the serial file */
 			strncpy(buf[2],serialfile,BSIZE-4);
 			strcat(buf[2],".old");
+			BIO_free(in);
+			BIO_free(out);
+			in=NULL;
+			out=NULL;
 			if (rename(serialfile,buf[2]) < 0)
 				{
 				fprintf(stderr,"unabel to rename %s to %s\n",
