@@ -54,7 +54,11 @@
 #include "envelope.h"
 #include "objects.h"
 #include "x509.h"
+#ifdef NO_MD5
+#include <md5.h>
+#else
 #include "md5.h"
+#endif
 #include "pem.h"
 
 #ifndef NOPROTO
