@@ -86,6 +86,7 @@
  * -key file	- make a request using key in file (or use it for verification).
  * -keyform	- key file format.
  * -newkey	- make a key and a request.
+ * -modulus	- print the RSA modulus
  * -x509	- output a self signed X509 structure instead.
  * -asn1-kludge	- output new certificate request in a format that some CA's
  *		  require.  This format is wrong
@@ -119,12 +120,13 @@ char **argv;
 	X509 *x509ss=NULL;
 	X509_REQ *req=NULL;
 	RSA *rsa=NULL;
-	int i,badops=0,new=0,newkey= -1;
+	int i,badops=0,newreq=0,newkey= -1;
 	BIO *in=NULL,*out=NULL;
 	int informat,outformat,verify=0,noout=0,text=0,keyform=FORMAT_PEM;
 	int nodes=0,kludge=0;
 	char *infile,*outfile,*prog,*keyfile=NULL,*template=NULL,*keyout=NULL;
 	EVP_CIPHER *cipher=EVP_des_ede3_cbc();
+	int modulus=0;
 	char *p;
 
 	apps_startup();
@@ -159,7 +161,7 @@ char **argv;
 			keyfile= *(++argv);
 			}
 		else if (strcmp(*argv,"-new") == 0)
-			new=1;
+			newreq=1;
 		else if (strcmp(*argv,"-config") == 0)
 			{	
 			if (--argc < 1) goto bad;
@@ -189,8 +191,10 @@ char **argv;
 			{
 			if (--argc < 1) goto bad;
 			newkey= atoi(*(++argv));
-			new=1;
+			newreq=1;
 			}
+		else if (strcmp(*argv,"-modulus") == 0)
+			modulus=1;
 		else if (strcmp(*argv,"-verify") == 0)
 			verify=1;
 		else if (strcmp(*argv,"-nodes") == 0)
@@ -228,6 +232,7 @@ bad:
 		fprintf(stderr," -outform arg   output format - one of DER TXT PEM\n");
 		fprintf(stderr," -in arg        inout file\n");
 		fprintf(stderr," -out arg       output file\n");
+		fprintf(stderr," -modulus       print the RSA public key modulus\n");
 		fprintf(stderr," -text          text form of request\n");
 		fprintf(stderr," -noout         do not output REQ\n");
 		fprintf(stderr," -verify        verify signature on REQ\n");
@@ -296,7 +301,7 @@ bad:
 			}
 		}
 
-	if (new && (rsa == NULL))
+	if (newreq && (rsa == NULL))
 		{
 		char *randfile;
 		char buffer[200];
@@ -382,7 +387,7 @@ loop:
 		fprintf(stderr,"-----\n");
 		}
 
-	if (!new)
+	if (!newreq)
 		{
 		/* Since we are using a pre-existing certificate
 		 * request, the kludge 'format' info should not be
@@ -416,7 +421,7 @@ loop:
 			}
 		}
 
-	if (new || x509)
+	if (newreq || x509)
 		{
 		if (rsa == NULL)
 			{
@@ -529,7 +534,7 @@ loop:
 			fprintf(stderr,"verify OK\n");
 		}
 
-	if (noout && !text)
+	if (noout && !text && !modulus)
 		{
 		ex=0;
 		goto end;
@@ -558,6 +563,35 @@ loop:
 			X509_REQ_print(out,req);
 		}
 
+	if (modulus)
+		{
+		EVP_PKEY *pkey;
+
+		if (x509)
+			pkey=X509_extract_key(x509ss);
+		else
+			pkey=X509_REQ_extract_key(req);
+		if (pkey == NULL)
+			{
+			fprintf(stdout,"Modulus=unavailable\n");
+			ERR_print_errors(bio_err);
+			goto end; 
+			}
+		fprintf(stdout,"Modulus=");
+		switch (pkey->type)
+			{
+		case EVP_PKEY_RSA:
+		case EVP_PKEY_RSA2:
+			BN_print(out,pkey->pkey.rsa->n);
+			break;
+		default:
+			fprintf(stdout,"Wrong Algorithm type");
+			break;
+			}
+		fprintf(stdout,"\n");
+		EVP_PKEY_free(pkey);
+		}
+
 	if (!noout && !x509)
 		{
 		if 	(outformat == FORMAT_ASN1)
