@@ -119,8 +119,6 @@ static int ssl=0;
 static SSL_CTX *m_ctx=NULL;
 static char *key_file=NULL;
 static char *cert_file="./server.pem";
-static RSA *key=NULL;
-static X509 *cert=NULL;
 
 int MAIN(argc, argv)
 int argc;
@@ -224,7 +222,6 @@ int port;
 	int asock;
 	EIO_CTX *dctx;
 	EIO_HANDLE *ah;
-	BIO *in=NULL;
 
 	if (!init_server(&asock,port))
 		return(0);
@@ -237,30 +234,21 @@ int port;
 
 	if (ssl)
 		{
-		in=BIO_new(BIO_s_file());
-		if (in == NULL)
-			{
-			ERR_print_errors(bio_err);
-			goto err;
-			}
-
-		if (BIO_read_filename(in,key_file) <= 0)
+		if (SSL_CTX_use_RSAPrivateKey_file(m_ctx,key_file,
+			SSL_FILETYPE_PEM) <= 0)
 			{
 			fprintf(stderr,"error opening key file\n");
 			perror(key_file);
 			goto err;
 			}
-		if ((key=PEM_read_bio_RSAPrivateKey(in,NULL,NULL)) == NULL)
-			goto err;
 
-		if (BIO_read_filename(in,cert_file) <= 0)
+		if (SSL_CTX_use_certificate_file(m_ctx,cert_file,
+			SSL_FILETYPE_PEM) <= 0)
 			{
 			fprintf(stderr,"error opening certificate file\n");
 			perror(cert_file);
 			goto err;
 			}
-
-		if ((cert=PEM_read_bio_X509(in,NULL,NULL)) == NULL) goto err;
 		}
 
 	/* Setup an accept socket */
@@ -280,14 +268,8 @@ int port;
 #endif
 
 	fprintf(stderr,"start\n");
-	if (in != NULL)
-		{
-		BIO_free(in);
-		in=NULL;
-		}
 	ret=EIO_loop(dctx);
 err:
-	if (in != NULL) BIO_free(in);
 	SHUTDOWN(asock);
 	sock_cleanup();
 	EIO_CTX_free(dctx,BUF_STUFF_free);
@@ -332,8 +314,6 @@ EIO_HANDLE *dh;
 
 			s=(SSL *)SSL_new(m_ctx);
 			if (m_Pause) s->debug=1;
-			SSL_use_certificate(s,cert);
-			SSL_use_RSAPrivateKey(s,key);
 			SSL_set_fd(s,sock);
 			/* put the SSL data in the shared struct */
 			b->data=(char *)s;
