@@ -95,9 +95,21 @@ struct tms {
 #include <sys/param.h>
 #endif
 
+#ifdef NO_DES
+#include <des.h>
+#else
 #include "des.h"
+#endif
+#ifdef NO_MD2
+#include <md2.h>
+#else
 #include "md2.h"
+#endif
+#ifdef NO_MD5
+#include <md5.h>
+#else
 #include "md5.h"
+#endif
 #include "sha.h"
 #ifndef NO_RC4
 #include "rc4.h"
