@@ -170,7 +170,7 @@ char *file;
 		goto end;
 		}
 	fprintf(stdout,"%s: ",(file == NULL)?"stdin":file);
-	i=X509_cert_verify(ctx,x,cb);
+	i=X509_cert_verify(ctx,x,cb,NULL);
 	ret=0;
 end:
 	if (i)
