@@ -88,6 +88,9 @@ static char *usage[]={
 " -issuer         - print issuer DN\n",
 " -startdate      - notBefore field\n",
 " -enddate        - notAfter field\n",
+" -dates          - both Before and After dates\n",
+" -modulus        - print the private key modulus\n",
+" -fingerprint    - print the certificate fingerprint\n",
 " -noout          - no certificate output\n",
 
 " -days arg       - How long till expiry of a signed certificate - def 30 days\n",
@@ -134,11 +137,12 @@ char **argv;
 	char *CAkeyfile=NULL,*str=NULL,*CAserial=NULL;
 	int text=0,serial=0,hash=0,subject=0,issuer=0,startdate=0,enddate=0;
 	int noout=0,sign_flag=0,CA_flag=0,CA_createserial=0;
-	int x509req=0,days=DEF_DAYS,reqfile=0;
+	int x509req=0,days=DEF_DAYS,reqfile=0,modulus=0;
 	char **pp;
 	CERTIFICATE_CTX *ctx=NULL;
 	X509_REQ *rq=NULL;
 	RSA *r=NULL;
+	int fingerprint=0;
 
 	apps_startup();
 
@@ -233,6 +237,8 @@ char **argv;
 			}
 		else if (strcmp(*argv,"-serial") == 0)
 			serial= ++num;
+		else if (strcmp(*argv,"-modulus") == 0)
+			modulus= ++num;
 		else if (strcmp(*argv,"-x509toreq") == 0)
 			x509req= ++num;
 		else if (strcmp(*argv,"-text") == 0)
@@ -243,6 +249,8 @@ char **argv;
 			subject= ++num;
 		else if (strcmp(*argv,"-issuer") == 0)
 			issuer= ++num;
+		else if (strcmp(*argv,"-fingerprint") == 0)
+			fingerprint= ++num;
 		else if (strcmp(*argv,"-dates") == 0)
 			{
 			startdate= ++num;
@@ -432,7 +440,7 @@ bad:
 				}
 			if (serial == i)
 				{
-				fprintf(stdout,"serial ");
+				fprintf(stdout,"serial=");
 				i2a_ASN1_INTEGER(STDout,x->cert_info->serialNumber);
 				}
 			if (hash == i)
@@ -440,6 +448,31 @@ bad:
 				fprintf(stdout,"%08lx\n",
 					X509_subject_name_hash(x));
 				}
+			if (modulus == i)
+				{
+				EVP_PKEY *pkey;
+
+				pkey=X509_extract_key(x);
+				if (pkey == NULL)
+					{
+					fprintf(stdout,"Modulus=unavailable\n");
+					ERR_print_errors(bio_err);
+					goto end;
+					}
+				fprintf(stdout,"Modulus=");
+				switch (pkey->type)
+					{
+				case EVP_PKEY_RSA:
+				case EVP_PKEY_RSA2:
+					BN_print(STDout,pkey->pkey.rsa->n);
+					break;
+				default:
+					fprintf(stdout,"Wrong Algorithm type");
+					break;
+					}
+				fprintf(stdout,"\n");
+				EVP_PKEY_free(pkey);
+				}
 			if (text == i)
 				{
 				X509_print(out,x);
@@ -458,6 +491,30 @@ bad:
 					x->cert_info->validity->notAfter);
 				BIO_puts(STDout,"\n");
 				}
+			if (fingerprint == i)
+				{
+				int j,n;
+				unsigned char *p,*pp;
+				unsigned char md[MD5_DIGEST_LENGTH];
+
+				n=i2d_X509(x,NULL);
+				p=(unsigned char *)malloc(n);
+				if (p == NULL)
+					{
+					fprintf(stderr,"out of memory\n");
+					goto end;
+					}
+				pp=p;
+				n=i2d_X509(x,&pp);
+				MD5(p,(unsigned long)n,md);
+				fprintf(stdout,"Fingerprint=");
+				for (j=0; j<MD5_DIGEST_LENGTH; j++)
+					{
+					fprintf(stdout,"%02X%c",md[j],
+						(j+1 == MD5_DIGEST_LENGTH)
+						?'\n':':');
+					}
+				}
 
 			/* should be in the library */
 			if (sign_flag == i)
@@ -670,7 +727,7 @@ int days;
 	 * the cert for it's very own :-) */
 	x->references++;
 	/* NOTE: this certificate can/should be self signed */
-	if (!X509_cert_verify(ctx,x,callb))
+	if (!X509_cert_verify(ctx,x,callb,NULL))
 		goto end;
 
 	X509_NAME_free(x->cert_info->issuer);
