@@ -47,7 +47,11 @@
 
 #include <stdio.h>
 #include "rc4.h"
+#ifdef NO_DES
+#include <des.h>
+#else
 #include "des.h"
+#endif
 
 /* show how stream ciphers are not very good.  The mac has no affect
  * on RC4 while it does for cfb DES
