@@ -52,6 +52,7 @@
 extern "C" {
 #endif
 
+#include <time.h>
 #include "bn.h"
 #include "stack.h"
 
@@ -243,7 +244,7 @@ ASN1_BIT_STRING *d2i_ASN1_INTEGER(ASN1_BIT_STRING **a,unsigned char **pp,
 			long length);
 int ASN1_UTCTIME_check(ASN1_UTCTIME *a);
 ASN1_UTCTIME *ASN1_UTCTIME_dup(ASN1_UTCTIME *a);
-ASN1_UTCTIME *ASN1_UTCTIME_set(ASN1_UTCTIME *s,long t);
+ASN1_UTCTIME *ASN1_UTCTIME_set(ASN1_UTCTIME *s,time_t t);
 
 
 int		i2d_ASN1_OCTET_STRING(ASN1_BIT_STRING *a,unsigned char **pp);
@@ -465,71 +466,70 @@ ASN1_METHOD *ASN1_RSAPrivateKey_meth();
 #define ASN1_F_D2I_PKCS7_SIGNED				 144
 #define ASN1_F_D2I_PKCS7_SIGNER_INFO			 145
 #define ASN1_F_D2I_PKCS7_SIGN_ENVELOPE			 146
-#define ASN1_F_D2I_PKEY					 147
-#define ASN1_F_D2I_PRIVATEKEY				 148
-#define ASN1_F_D2I_PUBLICKEY				 149
-#define ASN1_F_D2I_RSAPRIVATEKEY			 150
-#define ASN1_F_D2I_RSAPUBLICKEY				 151
-#define ASN1_F_D2I_X509					 152
-#define ASN1_F_D2I_X509_ALGOR				 153
-#define ASN1_F_D2I_X509_ATTRIBUTE			 154
-#define ASN1_F_D2I_X509_CINF				 155
-#define ASN1_F_D2I_X509_CRL				 156
-#define ASN1_F_D2I_X509_CRL_INFO			 157
-#define ASN1_F_D2I_X509_KEY				 158
-#define ASN1_F_D2I_X509_NAME				 159
-#define ASN1_F_D2I_X509_NAME_ENTRY			 160
-#define ASN1_F_D2I_X509_PKEY				 161
-#define ASN1_F_D2I_X509_PUBKEY				 162
-#define ASN1_F_D2I_X509_REQ				 163
-#define ASN1_F_D2I_X509_REQ_INFO			 164
-#define ASN1_F_D2I_X509_REVOKED				 165
-#define ASN1_F_D2I_X509_SIG				 166
-#define ASN1_F_D2I_X509_VAL				 167
-#define ASN1_F_I2A_ASN1_OBJECT				 168
-#define ASN1_F_I2D_ASN1_HEADER				 169
-#define ASN1_F_I2D_DHPARAMS				 170
-#define ASN1_F_I2D_DSAPRIVATEKEY			 171
-#define ASN1_F_I2D_DSAPUBLICKEY				 172
-#define ASN1_F_I2D_NETSCAPE_RSA				 173
-#define ASN1_F_I2D_PKCS7				 174
-#define ASN1_F_I2D_PRIVATEKEY				 175
-#define ASN1_F_I2D_PUBLICKEY				 176
-#define ASN1_F_I2D_RSAPRIVATEKEY			 177
-#define ASN1_F_I2D_RSAPUBLICKEY				 178
-#define ASN1_F_I2D_X509_ATTRIBUTE			 179
-#define ASN1_F_NETSCAPE_PKEY_NEW			 180
-#define ASN1_F_NETSCAPE_SPKAC_NEW			 181
-#define ASN1_F_NETSCAPE_SPKI_NEW			 182
-#define ASN1_F_PKCS7_DIGEST_NEW				 183
-#define ASN1_F_PKCS7_ENCRYPT_NEW			 184
-#define ASN1_F_PKCS7_ENC_CONTENT_NEW			 185
-#define ASN1_F_PKCS7_ENVELOPE_NEW			 186
-#define ASN1_F_PKCS7_ISSUER_AND_SERIAL_NEW		 187
-#define ASN1_F_PKCS7_NEW				 188
-#define ASN1_F_PKCS7_RECIP_INFO_NEW			 189
-#define ASN1_F_PKCS7_SIGNED_NEW				 190
-#define ASN1_F_PKCS7_SIGNER_INFO_NEW			 191
-#define ASN1_F_PKCS7_SIGN_ENVELOPE_NEW			 192
-#define ASN1_F_X509_ALGOR_NEW				 193
-#define ASN1_F_X509_ATTRIBUTE_NEW			 194
-#define ASN1_F_X509_CINF_NEW				 195
-#define ASN1_F_X509_CRL_INFO_NEW			 196
-#define ASN1_F_X509_CRL_NEW				 197
-#define ASN1_F_X509_DHPARAMS_NEW			 198
-#define ASN1_F_X509_INFO_NEW				 199
-#define ASN1_F_X509_KEY_NEW				 200
-#define ASN1_F_X509_NAME_ENTRY_NEW			 201
-#define ASN1_F_X509_NAME_NEW				 202
-#define ASN1_F_X509_NEW					 203
-#define ASN1_F_X509_PKEY_NEW				 204
-#define ASN1_F_X509_PUBKEY_NEW				 205
-#define ASN1_F_X509_REQ_INFO_NEW			 206
-#define ASN1_F_X509_REQ_NEW				 207
-#define ASN1_F_X509_REVOKED_NEW				 208
-#define ASN1_F_X509_SIG_NEW				 209
-#define ASN1_F_X509_VAL_FREE				 210
-#define ASN1_F_X509_VAL_NEW				 211
+#define ASN1_F_D2I_PRIVATEKEY				 147
+#define ASN1_F_D2I_PUBLICKEY				 148
+#define ASN1_F_D2I_RSAPRIVATEKEY			 149
+#define ASN1_F_D2I_RSAPUBLICKEY				 150
+#define ASN1_F_D2I_X509					 151
+#define ASN1_F_D2I_X509_ALGOR				 152
+#define ASN1_F_D2I_X509_ATTRIBUTE			 153
+#define ASN1_F_D2I_X509_CINF				 154
+#define ASN1_F_D2I_X509_CRL				 155
+#define ASN1_F_D2I_X509_CRL_INFO			 156
+#define ASN1_F_D2I_X509_KEY				 157
+#define ASN1_F_D2I_X509_NAME				 158
+#define ASN1_F_D2I_X509_NAME_ENTRY			 159
+#define ASN1_F_D2I_X509_PKEY				 160
+#define ASN1_F_D2I_X509_PUBKEY				 161
+#define ASN1_F_D2I_X509_REQ				 162
+#define ASN1_F_D2I_X509_REQ_INFO			 163
+#define ASN1_F_D2I_X509_REVOKED				 164
+#define ASN1_F_D2I_X509_SIG				 165
+#define ASN1_F_D2I_X509_VAL				 166
+#define ASN1_F_I2A_ASN1_OBJECT				 167
+#define ASN1_F_I2D_ASN1_HEADER				 168
+#define ASN1_F_I2D_DHPARAMS				 169
+#define ASN1_F_I2D_DSAPRIVATEKEY			 170
+#define ASN1_F_I2D_DSAPUBLICKEY				 171
+#define ASN1_F_I2D_NETSCAPE_RSA				 172
+#define ASN1_F_I2D_PKCS7				 173
+#define ASN1_F_I2D_PRIVATEKEY				 174
+#define ASN1_F_I2D_PUBLICKEY				 175
+#define ASN1_F_I2D_RSAPRIVATEKEY			 176
+#define ASN1_F_I2D_RSAPUBLICKEY				 177
+#define ASN1_F_I2D_X509_ATTRIBUTE			 178
+#define ASN1_F_NETSCAPE_PKEY_NEW			 179
+#define ASN1_F_NETSCAPE_SPKAC_NEW			 180
+#define ASN1_F_NETSCAPE_SPKI_NEW			 181
+#define ASN1_F_PKCS7_DIGEST_NEW				 182
+#define ASN1_F_PKCS7_ENCRYPT_NEW			 183
+#define ASN1_F_PKCS7_ENC_CONTENT_NEW			 184
+#define ASN1_F_PKCS7_ENVELOPE_NEW			 185
+#define ASN1_F_PKCS7_ISSUER_AND_SERIAL_NEW		 186
+#define ASN1_F_PKCS7_NEW				 187
+#define ASN1_F_PKCS7_RECIP_INFO_NEW			 188
+#define ASN1_F_PKCS7_SIGNED_NEW				 189
+#define ASN1_F_PKCS7_SIGNER_INFO_NEW			 190
+#define ASN1_F_PKCS7_SIGN_ENVELOPE_NEW			 191
+#define ASN1_F_X509_ALGOR_NEW				 192
+#define ASN1_F_X509_ATTRIBUTE_NEW			 193
+#define ASN1_F_X509_CINF_NEW				 194
+#define ASN1_F_X509_CRL_INFO_NEW			 195
+#define ASN1_F_X509_CRL_NEW				 196
+#define ASN1_F_X509_DHPARAMS_NEW			 197
+#define ASN1_F_X509_INFO_NEW				 198
+#define ASN1_F_X509_KEY_NEW				 199
+#define ASN1_F_X509_NAME_ENTRY_NEW			 200
+#define ASN1_F_X509_NAME_NEW				 201
+#define ASN1_F_X509_NEW					 202
+#define ASN1_F_X509_PKEY_NEW				 203
+#define ASN1_F_X509_PUBKEY_NEW				 204
+#define ASN1_F_X509_REQ_INFO_NEW			 205
+#define ASN1_F_X509_REQ_NEW				 206
+#define ASN1_F_X509_REVOKED_NEW				 207
+#define ASN1_F_X509_SIG_NEW				 208
+#define ASN1_F_X509_VAL_FREE				 209
+#define ASN1_F_X509_VAL_NEW				 210
 
 /* Reason codes. */
 #define ASN1_R_BAD_CLASS				 100
