@@ -1,5 +1,5 @@
-/* lib/asn1/p7_s_e.c */
-/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au)
+/* crypto/asn1/p7_s_e.c */
+/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
  * 
  * This file is part of an SSL implementation written
@@ -46,7 +46,7 @@
  */
 
 #include <stdio.h>
-#include "crypto.h"
+#include "cryptlib.h"
 #include "asn1_mac.h"
 #include "x509.h"
 
