@@ -1,5 +1,5 @@
-/* lib/asn1/x_crl.c */
-/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au)
+/* crypto/asn1/x_crl.c */
+/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
  * 
  * This file is part of an SSL implementation written
@@ -46,7 +46,7 @@
  */
 
 #include <stdio.h>
-#include "crypto.h"
+#include "cryptlib.h"
 #include "asn1_mac.h"
 #include "x509.h"
 
@@ -111,7 +111,7 @@ unsigned char **pp;
 	M_ASN1_I2D_len(a->issuer,i2d_X509_NAME);
 	M_ASN1_I2D_len(a->lastUpdate,i2d_ASN1_UTCTIME);
 	M_ASN1_I2D_len(a->nextUpdate,i2d_ASN1_UTCTIME);
-	M_ASN1_I2D_len_SEQ(a->revoked,i2d_X509_REVOKED);
+	M_ASN1_I2D_len_SEQ_opt(a->revoked,i2d_X509_REVOKED);
 
 	M_ASN1_I2D_seq_total();
 
@@ -119,7 +119,7 @@ unsigned char **pp;
 	M_ASN1_I2D_put(a->issuer,i2d_X509_NAME);
 	M_ASN1_I2D_put(a->lastUpdate,i2d_ASN1_UTCTIME);
 	M_ASN1_I2D_put(a->nextUpdate,i2d_ASN1_UTCTIME);
-	M_ASN1_I2D_put_SEQ(a->revoked,i2d_X509_REVOKED);
+	M_ASN1_I2D_put_SEQ_opt(a->revoked,i2d_X509_REVOKED);
 
 	M_ASN1_I2D_finish();
 	}
@@ -129,7 +129,7 @@ X509_CRL_INFO **a;
 unsigned char **pp;
 long length;
 	{
-	unsigned int i;
+	int i;
 	M_ASN1_D2I_vars(a,X509_CRL_INFO *,X509_CRL_INFO_new);
 
 	M_ASN1_D2I_Init();
@@ -138,7 +138,7 @@ long length;
 	M_ASN1_D2I_get(ret->issuer,d2i_X509_NAME);
 	M_ASN1_D2I_get(ret->lastUpdate,d2i_ASN1_UTCTIME);
 	M_ASN1_D2I_get(ret->nextUpdate,d2i_ASN1_UTCTIME);
-	M_ASN1_D2I_get_seq(ret->revoked,d2i_X509_REVOKED);
+	M_ASN1_D2I_get_seq_opt(ret->revoked,d2i_X509_REVOKED);
 
 	if (ret->revoked != NULL)
 		{
@@ -251,9 +251,15 @@ void X509_CRL_free(a)
 X509_CRL *a;
 	{
 	if (a == NULL) return;
-	CS_BEGIN;
-	if (--a->references > 0) return;
-	CS_END;
+
+	CRYPTO_w_lock(CRYPTO_LOCK_X509_CRL);
+	if (--a->references > 0)
+		{
+		CRYPTO_w_unlock(CRYPTO_LOCK_X509_CRL);
+		return;
+		}
+	CRYPTO_w_unlock(CRYPTO_LOCK_X509_CRL);
+
 	X509_CRL_INFO_free(a->crl);
 	X509_ALGOR_free(a->sig_alg);
 	ASN1_BIT_STRING_free(a->signature);
