@@ -1,5 +1,5 @@
-/* lib/asn1/x_req.c */
-/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au)
+/* crypto/asn1/x_req.c */
+/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
  * 
  * This file is part of an SSL implementation written
@@ -46,7 +46,7 @@
  */
 
 #include <stdio.h>
-#include "crypto.h"
+#include "cryptlib.h"
 #include "asn1_mac.h"
 #include "x509.h"
 
@@ -211,9 +211,15 @@ void X509_REQ_free(a)
 X509_REQ *a;
 	{
 	if (a == NULL) return;
-	CS_BEGIN;
-	if (--a->references > 0) return;
-	CS_END;
+
+	CRYPTO_w_lock(CRYPTO_LOCK_X509_REQ);
+	if (--a->references > 0)
+		{
+		CRYPTO_w_unlock(CRYPTO_LOCK_X509_REQ);
+		return;
+		}
+	CRYPTO_w_unlock(CRYPTO_LOCK_X509_REQ);
+
 	X509_REQ_INFO_free(a->req_info);
 	X509_ALGOR_free(a->sig_alg);
 	ASN1_BIT_STRING_free(a->signature);
