@@ -65,7 +65,7 @@
 #define IS_ALPHA_NUMERIC(a)	(CONF_type[(a)&0x7f]&CONF_ALPHA_NUMERIC)
 #define IS_QUOTE(a)		(CONF_type[(a)&0x7f]&CONF_QUOTE)
 
-unsigned short CONF_type[128]={
+static unsigned short CONF_type[128]={
 	0x008,0x000,0x000,0x000,0x000,0x000,0x000,0x000,
 	0x000,0x010,0x010,0x000,0x000,0x010,0x000,0x000,
 	0x000,0x000,0x000,0x000,0x000,0x000,0x000,0x000,
