@@ -300,7 +300,7 @@ char *argv[];
 	printf("Doing ecb\n");
 	for (i=0; i<NUM_TESTS; i++)
 		{
-		if ((j=key_sched((C_Block *)(key_data[i]),ks)) != 0)
+		if ((j=des_key_sched((C_Block *)(key_data[i]),ks)) != 0)
 			{
 			printf("Key error %2d:%d\n",i+1,j);
 			err=1;
@@ -329,17 +329,17 @@ char *argv[];
 	printf("Doing ede ecb\n");
 	for (i=0; i<(NUM_TESTS-1); i++)
 		{
-		if ((j=key_sched((C_Block *)(key_data[i]),ks)) != 0)
+		if ((j=des_key_sched((C_Block *)(key_data[i]),ks)) != 0)
 			{
 			err=1;
 			printf("Key error %2d:%d\n",i+1,j);
 			}
-		if ((j=key_sched((C_Block *)(key_data[i+1]),ks2)) != 0)
+		if ((j=des_key_sched((C_Block *)(key_data[i+1]),ks2)) != 0)
 			{
 			printf("Key error %2d:%d\n",i+2,j);
 			err=1;
 			}
-		if ((j=key_sched((C_Block *)(key_data[i+2]),ks3)) != 0)
+		if ((j=des_key_sched((C_Block *)(key_data[i+2]),ks3)) != 0)
 			{
 			printf("Key error %2d:%d\n",i+3,j);
 			err=1;
@@ -368,7 +368,7 @@ char *argv[];
 		}
 
 	printf("Doing cbc\n");
-	if ((j=key_sched((C_Block *)cbc_key,ks)) != 0)
+	if ((j=des_key_sched((C_Block *)cbc_key,ks)) != 0)
 		{
 		printf("Key error %d\n",j);
 		err=1;
@@ -390,17 +390,17 @@ char *argv[];
 		}
 
 	printf("Doing ede cbc\n");
-	if ((j=key_sched((C_Block *)cbc_key,ks)) != 0)
+	if ((j=des_key_sched((C_Block *)cbc_key,ks)) != 0)
 		{
 		printf("Key error %d\n",j);
 		err=1;
 		}
-	if ((j=key_sched((C_Block *)cbc2_key,ks2)) != 0)
+	if ((j=des_key_sched((C_Block *)cbc2_key,ks2)) != 0)
 		{
 		printf("Key error %d\n",j);
 		err=1;
 		}
-	if ((j=key_sched((C_Block *)cbc3_key,ks3)) != 0)
+	if ((j=des_key_sched((C_Block *)cbc3_key,ks3)) != 0)
 		{
 		printf("Key error %d\n",j);
 		err=1;
@@ -433,7 +433,7 @@ char *argv[];
 		}
 
 	printf("Doing pcbc\n");
-	if ((j=key_sched((C_Block *)cbc_key,ks)) != 0)
+	if ((j=des_key_sched((C_Block *)cbc_key,ks)) != 0)
 		{
 		printf("Key error %d\n",j);
 		err=1;
@@ -496,7 +496,7 @@ char *argv[];
 	printf("done\n");
 
 	printf("Doing ofb\n");
-	key_sched((C_Block *)ofb_key,ks);
+	des_key_sched((C_Block *)ofb_key,ks);
 	memcpy(ofb_tmp,ofb_iv,sizeof(ofb_iv));
 	des_ofb_encrypt(plain,ofb_buf1,64,(long)sizeof(plain)/8,ks,
 		(C_Block *)ofb_tmp);
@@ -515,7 +515,7 @@ char *argv[];
 		}
 
 	printf("Doing ofb64\n");
-	key_sched((C_Block *)ofb_key,ks);
+	des_key_sched((C_Block *)ofb_key,ks);
 	memcpy(ofb_tmp,ofb_iv,sizeof(ofb_iv));
 	memset(ofb_buf1,0,sizeof(ofb_buf1));
 	memset(ofb_buf2,0,sizeof(ofb_buf1));
@@ -541,7 +541,7 @@ char *argv[];
 		}
 
 	printf("Doing ede_ofb64\n");
-	key_sched((C_Block *)ofb_key,ks);
+	des_key_sched((C_Block *)ofb_key,ks);
 	memcpy(ofb_tmp,ofb_iv,sizeof(ofb_iv));
 	memset(ofb_buf1,0,sizeof(ofb_buf1));
 	memset(ofb_buf2,0,sizeof(ofb_buf1));
@@ -567,13 +567,13 @@ char *argv[];
 		}
 
 	printf("Doing cbc_cksum\n");
-	key_sched((C_Block *)cbc_key,ks);
-	cs=cbc_cksum((C_Block *)cbc_data,(C_Block *)cret,
+	des_key_sched((C_Block *)cbc_key,ks);
+	cs=des_cbc_cksum((C_Block *)cbc_data,(C_Block *)cret,
 		(long)strlen(cbc_data),ks,(C_Block *)cbc_iv);
 	if (cs != cbc_cksum_ret)
 		{
 		printf("bad return value (%08lX), should be %08lX\n",
-			cs,cbc_cksum_ret);
+			(unsigned long)cs,(unsigned long)cbc_cksum_ret);
 		err=1;
 		}
 	if (memcmp(cret,cbc_cksum_data,8) != 0)
@@ -607,31 +607,32 @@ char *argv[];
 	}
 	if (cs != 0x70d7a63aL)
 		{
-		printf("quad_cksum error, ret %08lx should be 70d7a63a\n",cs);
+		printf("quad_cksum error, ret %08lx should be 70d7a63a\n",
+			(unsigned long)cs);
 		err=1;
 		}
 	if (lqret[0] != 0x327eba8dL)
 		{
 		printf("quad_cksum error, out[0] %08lx is not %08lx\n",
-			lqret[0],0x327eba8dL);
+			(unsigned long)lqret[0],0x327eba8dL);
 		err=1;
 		}
 	if (lqret[1] != 0x201a49ccL)
 		{
 		printf("quad_cksum error, out[1] %08lx is not %08lx\n",
-			lqret[1],0x201a49ccL);
+			(unsigned long)lqret[1],0x201a49ccL);
 		err=1;
 		}
 	if (lqret[2] != 0x70d7a63aL)
 		{
 		printf("quad_cksum error, out[2] %08lx is not %08lx\n",
-			lqret[2],0x70d7a63aL);
+			(unsigned long)lqret[2],0x70d7a63aL);
 		err=1;
 		}
 	if (lqret[3] != 0x501c2c26L)
 		{
 		printf("quad_cksum error, out[3] %08lx is not %08lx\n",
-			lqret[3],0x501c2c26L);
+			(unsigned long)lqret[3],0x501c2c26L);
 		err=1;
 		}
 
@@ -697,7 +698,7 @@ unsigned char *cfb_cipher;
 	des_key_schedule ks;
 	int i,err=0;
 
-	key_sched((C_Block *)cfb_key,ks);
+	des_key_sched((C_Block *)cfb_key,ks);
 	memcpy(cfb_tmp,cfb_iv,sizeof(cfb_iv));
 	des_cfb_encrypt(plain,cfb_buf1,bits,(long)sizeof(plain),ks,
 		(C_Block *)cfb_tmp,DES_ENCRYPT);
@@ -727,7 +728,7 @@ unsigned char *cfb_cipher;
 	des_key_schedule ks;
 	int err=0,i,n;
 
-	key_sched((C_Block *)cfb_key,ks);
+	des_key_sched((C_Block *)cfb_key,ks);
 	memcpy(cfb_tmp,cfb_iv,sizeof(cfb_iv));
 	n=0;
 	des_cfb64_encrypt(plain,cfb_buf1,(long)12,ks,
@@ -765,7 +766,7 @@ unsigned char *cfb_cipher;
 	des_key_schedule ks;
 	int err=0,i,n;
 
-	key_sched((C_Block *)cfb_key,ks);
+	des_key_sched((C_Block *)cfb_key,ks);
 	memcpy(cfb_tmp,cfb_iv,sizeof(cfb_iv));
 	n=0;
 	des_ede3_cfb64_encrypt(plain,cfb_buf1,(long)12,ks,ks,ks,
