@@ -1,5 +1,5 @@
-/* lib/evp/e_names.c */
-/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au)
+/* crypto/evp/e_names.c */
+/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
  * 
  * This file is part of an SSL implementation written
@@ -46,7 +46,7 @@
  */
 
 #include <stdio.h>
-#include "crypto.h"
+#include "cryptlib.h"
 #include "envelope.h"
 #include "objects.h"
 
@@ -55,80 +55,80 @@ char *name;
 	{
 	if (	(strcmp(name,SN_des_ecb) == 0) ||
 		(strcmp(name,LN_des_ecb) == 0))
-		return(     EVP_des_ecb);
+		return(     EVP_des_ecb());
 	if (	(strcmp(name,SN_des_cfb) == 0) ||
 		(strcmp(name,LN_des_cfb) == 0))
-		return(     EVP_des_cfb);
+		return(     EVP_des_cfb());
 	if (	(strcmp(name,SN_des_ede_cfb) == 0) ||
 		(strcmp(name,LN_des_ede_cfb) == 0))
-		return(	    EVP_des_ede_cfb);
+		return(	    EVP_des_ede_cfb());
 	if (	(strcmp(name,SN_des_ede3_cfb) == 0) ||
 		(strcmp(name,LN_des_ede3_cfb) == 0))
-		return(     EVP_des_ede3_cfb);
+		return(     EVP_des_ede3_cfb());
 	if (	(strcmp(name,SN_des_ofb) == 0) ||
 		(strcmp(name,LN_des_ofb) == 0))
-		return(     EVP_des_ofb);
+		return(     EVP_des_ofb());
 	if (	(strcmp(name,SN_des_ede_ofb) == 0) ||
 		(strcmp(name,LN_des_ede_ofb) == 0))
-		return(     EVP_des_ede_ofb);
+		return(     EVP_des_ede_ofb());
 	if (	(strcmp(name,SN_des_ede3_ofb) == 0) ||
 		(strcmp(name,LN_des_ede3_ofb) == 0))
-		return(     EVP_des_ede3_ofb);
+		return(     EVP_des_ede3_ofb());
 	if (	(strcmp(name,SN_des_cbc) == 0) ||
 		(strcmp(name,LN_des_cbc) == 0) ||
 		(strcmp(name,"DES") == 0) ||
 		(strcmp(name,"des") == 0))
-		return(     EVP_des_cbc);
+		return(     EVP_des_cbc());
 	if (	(strcmp(name,SN_des_ede_cbc) == 0) ||
 		(strcmp(name,LN_des_ede_cbc) == 0))
-		return(     EVP_des_ede_cbc);
+		return(     EVP_des_ede_cbc());
 	if (	(strcmp(name,SN_des_ede3_cbc) == 0) ||
 		(strcmp(name,LN_des_ede3_cbc) == 0) ||
 		(strcmp(name,"DES3") == 0) ||
 		(strcmp(name,"des3") == 0))
-		return(     EVP_des_ede3_cbc);
+		return(     EVP_des_ede3_cbc());
 	if (	(strcmp(name,SN_des_ede) == 0) ||
 		(strcmp(name,LN_des_ede) == 0))
-		return(     EVP_des_ede);
+		return(     EVP_des_ede());
 	if (	(strcmp(name,SN_des_ede3) == 0) ||
 		(strcmp(name,LN_des_ede3) == 0))
-		return(     EVP_des_ede3);
-#ifndef NORC4
+		return(     EVP_des_ede3());
+#ifndef NO_RC4
 	if (	(strcmp(name,SN_rc4) == 0) ||
 		(strcmp(name,LN_rc4) == 0))
-		return(     EVP_rc4);
+		return(     EVP_rc4());
 #endif
-#ifndef NOIDEA
+#ifndef NO_IDEA
 	if (	(strcmp(name,SN_idea_ecb) == 0) ||
 		(strcmp(name,LN_idea_ecb) == 0))
-		return(     EVP_idea_ecb);
+		return(     EVP_idea_ecb());
 	if (	(strcmp(name,SN_idea_cfb) == 0) ||
 		(strcmp(name,LN_idea_cfb) == 0))
-		return(     EVP_idea_cfb);
+		return(     EVP_idea_cfb());
 	if (	(strcmp(name,SN_idea_ofb) == 0) ||
 		(strcmp(name,LN_idea_ofb) == 0))
-		return(     EVP_idea_ofb);
+		return(     EVP_idea_ofb());
 	if (	(strcmp(name,SN_idea_cbc) == 0) ||
 		(strcmp(name,LN_idea_cbc) == 0) ||
 		(strcmp(name,"IDEA") == 0) ||
 		(strcmp(name,"idea") == 0))
-		return(     EVP_idea_cbc);
+		return(     EVP_idea_cbc());
 #endif
-#ifndef NORC2
+#ifndef NO_RC2
 	if (	(strcmp(name,SN_rc2_ecb) == 0) ||
 		(strcmp(name,LN_rc2_ecb) == 0))
-		return(     EVP_rc2_ecb);
+		return(     EVP_rc2_ecb());
 	if (	(strcmp(name,SN_rc2_cfb) == 0) ||
 		(strcmp(name,LN_rc2_cfb) == 0))
-		return(     EVP_rc2_cfb);
+		return(     EVP_rc2_cfb());
 	if (	(strcmp(name,SN_rc2_ofb) == 0) ||
 		(strcmp(name,LN_rc2_ofb) == 0))
-		return(     EVP_rc2_ofb);
+		return(     EVP_rc2_ofb());
 	if (	(strcmp(name,SN_rc2_cbc) == 0) ||
 		(strcmp(name,LN_rc2_cbc) == 0) ||
 		(strcmp(name,"RC2") == 0) ||
 		(strcmp(name,"rc2") == 0))
-		return(     EVP_rc2_cbc);
+		return(     EVP_rc2_cbc());
 #endif
 	return(NULL);
 	}
