@@ -1,5 +1,5 @@
-/* lib/evp/encode.c */
-/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au)
+/* crypto/evp/encode.c */
+/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
  * 
  * This file is part of an SSL implementation written
@@ -46,7 +46,7 @@
  */
 
 #include <stdio.h>
-#include "crypto.h"
+#include "cryptlib.h"
 #include "envelope.h"
 
 #define conv_bin2ascii(a)	(data_bin2ascii[(a)&0x3f])
@@ -172,8 +172,8 @@ int dlen;
 		{
 		if (i >= 3)
 			{
-			l=	((unsigned long)f[0]<<16L)|
-				((unsigned long)f[1]<< 8L)|f[2];
+			l=	(((unsigned long)f[0])<<16L)|
+				(((unsigned long)f[1])<< 8L)|f[2];
 			*(t++)=conv_bin2ascii(l>>18L);
 			*(t++)=conv_bin2ascii(l>>12L);
 			*(t++)=conv_bin2ascii(l>> 6L);
@@ -181,8 +181,8 @@ int dlen;
 			}
 		else
 			{
-			l=(f[0]<<16L);
-			if (i == 2) l|=(f[1]<<8L);
+			l=((unsigned long)f[0])<<16L;
+			if (i == 2) l|=((unsigned long)f[1]<<8L);
 
 			*(t++)=conv_bin2ascii(l>>18L);
 			*(t++)=conv_bin2ascii(l>>12L);
@@ -193,7 +193,7 @@ int dlen;
 		f+=3;
 		}
 
-	*(t++)='\0';
+	*t='\0';
 	return(ret);
 	}
 
@@ -308,10 +308,10 @@ int n;
 		if (	(a & 0x80) || (b & 0x80) ||
 			(c & 0x80) || (d & 0x80))
 			return(-1);
-		l=(	(unsigned long)(a<<18L)|
-			(unsigned long)(b<<12L)|
-			(unsigned long)(c<< 6L)|
-			(unsigned long)(d     ));
+		l=(	(((unsigned long)a)<<18L)|
+			(((unsigned long)b)<<12L)|
+			(((unsigned long)c)<< 6L)|
+			(((unsigned long)d)     ));
 		*(t++)=(unsigned char)(l>>16L)&0xff;
 		*(t++)=(unsigned char)(l>> 8L)&0xff;
 		*(t++)=(unsigned char)(l     )&0xff;
