@@ -1,5 +1,5 @@
-/* lib/evp/evp_key.c */
-/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au)
+/* crypto/evp/evp_key.c */
+/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
  * 
  * This file is part of an SSL implementation written
@@ -46,17 +46,39 @@
  */
 
 #include <stdio.h>
-#include "crypto.h"
+#include "cryptlib.h"
 #include "x509.h"
 #include "objects.h"
 #include "envelope.h"
 
+/* should be init to zeros. */
+static char prompt_string[80];
+
+void EVP_set_pw_prompt(prompt)
+char *prompt;
+	{
+	if (prompt == NULL)
+		prompt_string[0]='\0';
+	else
+		strncpy(prompt_string,prompt,79);
+	}
+
+char *EVP_get_pw_prompt()
+	{
+	if (prompt_string[0] == '\0')
+		return(NULL);
+	else
+		return(prompt_string);
+	}
+
 int EVP_read_pw_string(buf,len,prompt,verify)
 char *buf;
 int len;
 char *prompt;
 int verify;
 	{
+	if ((prompt == NULL) && (prompt_string[0] != '\0'))
+		prompt=prompt_string;
 	return(des_read_pw_string(buf,len,prompt,verify));
 	}
 
@@ -72,11 +94,11 @@ unsigned char *iv;
 	{
 	EVP_MD_CTX c;
 	unsigned char md_buf[EVP_MAX_MD_SIZE];
-	int nreq,i,niv=0,nkey=0,addmd=0,mds;
+	int niv,nkey,addmd=0;
+	unsigned int mds,i;
 
 	nkey=type->key_len;
 	niv=type->iv_len;
-	nreq=nkey+niv;
 
 	if (data == NULL) return(nkey);
 
@@ -90,7 +112,7 @@ unsigned char *iv;
 			EVP_DigestUpdate(&c,salt,8);
 		EVP_DigestFinal(&c,&(md_buf[0]),&mds);
 
-		for (i=1; i<count; i++)
+		for (i=1; i<(unsigned int)count; i++)
 			{
 			EVP_DigestInit(&c,md);
 			EVP_DigestUpdate(&c,&(md_buf[0]),mds);
