@@ -61,8 +61,19 @@ EVP_PKEY *pkey;
 	{
 	unsigned char m[EVP_MAX_MD_SIZE];
 	unsigned int m_len;
+	int i,ok=0,v;
 
-	if (pkey->type != ctx->digest->required_pkey_type)
+	for (i=0; i<4; i++)
+		{
+		v=ctx->digest->required_pkey_type[i];
+		if (v == 0) break;
+		if (pkey->type == v)
+			{
+			ok=1;
+			break;
+			}
+		}
+	if (!ok)
 		{
 		EVPerr(EVP_F_EVP_VERIFYFINAL,EVP_R_WRONG_PUBLIC_KEY_TYPE);
 		return(-1);
