@@ -50,7 +50,11 @@
 #include <stdio.h>
 #include "cryptlib.h"
 #include "bn.h"
+#ifdef NO_MD5
+#include <md5.h>
+#else
 #include "md5.h"
+#endif
 #include "rsa.h"
 #include "rand.h"
 
