@@ -60,6 +60,16 @@ extern "C" {
 
 #include <errno.h>
 
+#define ERR_NUM_ERRORS      10
+typedef struct err_state_st
+        {
+	unsigned long pid;
+	unsigned long err_buffer[ERR_NUM_ERRORS];
+	char *err_file[ERR_NUM_ERRORS];
+	int err_line[ERR_NUM_ERRORS];
+	int top,bottom;
+	} ERR_STATE;
+
 /* library */
 #define ERR_LIB_NONE		1
 #define ERR_LIB_SYS		2
@@ -158,10 +168,15 @@ void ERR_load_ERR_strings(void );
 void ERR_load_crypto_strings(void );
 void ERR_free_strings(void );
 
+void ERR_remove_state(unsigned long pid); /* if zero we look it up */
+ERR_STATE *ERR_get_state(void);
+
 #ifdef HEADER_LHASH_H
-LHASH *err_data(void );
+LHASH *ERR_get_string_table(void );
+LHASH *ERR_get_err_state_table(void );
 #else
-char *err_data(void );
+char *ERR_get_string_table(void );
+char *ERR_get_err_state_table(void );
 #endif
 
 #else
@@ -185,10 +200,15 @@ void ERR_load_ERR_strings();
 void ERR_load_crypto_strings();
 void ERR_free_strings();
 
+void ERR_remove_state();
+ERR_STATE *ERR_get_state();
+
 #ifdef HEADER_LHASH_H
-LHASH *err_data();
+LHASH *ERR_get_string_table();
+LHASH *ERR_get_err_state_table();
 #else
-char *err_data();
+char *ERR_get_string_table();
+char *ERR_get_err_state_table();
 #endif
 
 #endif
