@@ -172,7 +172,7 @@ long length;
 	cipher.c2=os.data[1];
 	cipher.c3=os.data[2];
 	cp=cp=(CIPHER *)OBJ_bsearch((char *)&cipher,(char *)ssl_ciphers,
-                        NUM_CIPHERS,sizeof(CIPHER),(int (*)())ssl_cipher_cmp);
+                        SSL_NUM_CIPHERS,sizeof(CIPHER),(int (*)())ssl_cipher_cmp);
 	if (cp == NULL)
 		{
 		free(os.data);
