@@ -97,6 +97,9 @@ SSL_CTX *SSL_CTX_new()
 	ret->cipher_list=NULL;
 
 	ret->cert=NULL;
+	ret->session_cache_mode=SSL_SESS_CACHE_SERVER;
+	/* We take the system default */
+	ret->session_timeout=0;
 	ret->sessions=lh_new(conn_hash,session_cmp);
 	if (ret->sessions == NULL) goto err;
 
@@ -125,6 +128,14 @@ SSL_CTX *SSL_CTX_new()
 	ret->conn_id=NULL;
 	ret->info_callback=NULL;
 
+	ret->app_verify_callback=NULL;
+	ret->app_verify_arg=NULL;
+
+	ret->default_read_ahead=0;
+	ret->default_verify_mode=SSL_VERIFY_NONE;
+	ret->default_verify_callback=NULL;
+	ret->default_cert=NULL;
+
 	return(ret);
 err:
 	if (ret != NULL) SSL_CTX_free(ret);
@@ -156,5 +167,26 @@ SSL_CTX *a;
 		free(a->cipher_list[0]);
 		free(a->cipher_list);
 		}
+	if (a->default_cert != NULL)
+		ssl_cert_free(a->default_cert);
 	free(a);
 	}
+
+void SSL_CTX_set_cert_verify_callback(ctx,cb,arg)
+SSL_CTX *ctx;
+int (*cb)();
+char *arg;
+	{
+	ctx->app_verify_callback=cb;
+	ctx->app_verify_arg=arg;
+	}
+
+void SSL_CTX_set_default_verify(ctx,mode,cb)
+SSL_CTX *ctx;
+int mode;
+int (*cb)();
+	{
+	ctx->default_verify_mode=mode;
+	ctx->default_verify_callback=cb;
+	}
+
