@@ -73,13 +73,13 @@ CERT *ssl_cert_new()
 void ssl_cert_free(c)
 CERT *c;
 	{
-	CRYPTO_w_lock(CRYPTO_LOCK_ssl_CERT);
+	CRYPTO_w_lock(CRYPTO_LOCK_SSL_CERT);
 	if (--c->references > 0)
 		{
-		CRYPTO_w_unlock(CRYPTO_LOCK_ssl_CERT);
+		CRYPTO_w_unlock(CRYPTO_LOCK_SSL_CERT);
 		return;
 		}
-	CRYPTO_w_unlock(CRYPTO_LOCK_ssl_CERT);
+	CRYPTO_w_unlock(CRYPTO_LOCK_SSL_CERT);
 
 	if (c->x509 != NULL) X509_free(c->x509);
 	if (c->privatekey != NULL) EVP_PKEY_free(c->privatekey);
@@ -107,7 +107,12 @@ unsigned char *data;
 		goto err;
 		}
 
-	i=X509_cert_verify(s->ctx->cert,x509,s->verify_callback);
+	if (s->ctx->app_verify_callback != NULL)
+		i=s->ctx->app_verify_callback(s->ctx->app_verify_arg,s,x509);
+	else
+		i=X509_cert_verify(s->ctx->cert,x509,s->verify_callback,
+			&s->verify_result);
+		
 	if ((s->verify_mode != SSL_VERIFY_NONE) && (!i))
 		{
 		SSLerr(SSL_F_SSL_SET_CERTIFICATE,ERR_R_X509_LIB);
