@@ -46,7 +46,11 @@
  */
 
 #include <stdio.h>
+#ifdef NO_MD5
+#include <md5.h>
+#else
 #include "md5.h"
+#endif
 #include "rand.h"
 #include "buffer.h"
 #include "objects.h"
@@ -212,7 +216,13 @@ SSL *s;
 			s->init_num=0;
 			ERR_clear_error();
 
-			if (SSL_add_session(s->ctx,s->session) &&
+			/* If we want to cache session-ids in the client
+			 * and we sucessfully add the session-id to the
+			 * cache, and there is a callback, then pass it out.
+			 */
+			if ((s->ctx->session_cache_mode &
+				SSL_SESS_CACHE_CLIENT) &&
+				SSL_add_session(s->ctx,s->session) &&
 				(s->ctx->new_session_cb != NULL))
 				{
 				CRYPTO_w_lock(CRYPTO_LOCK_SSL_SESSION);
@@ -226,8 +236,15 @@ SSL *s;
 					CRYPTO_w_unlock(CRYPTO_LOCK_SSL_SESSION);
 					}
 				}
-			s->ctx->sess_connect_good++;
+
+			/* auto flush every 32 connections */
+			if ((!(s->ctx->session_cache_mode &
+				SSL_SESS_CACHE_NO_AUTO_CLEAR)) &&
+				((s->ctx->sess_accept_good & 0x1f) == 0x1f))
+				SSL_flush_sessions(s->ctx,time(NULL));
+
 			ret=1;
+			s->ctx->sess_connect_good++;
 			goto end;
 			break;
 		default:
@@ -251,7 +268,7 @@ SSL *s;
 	unsigned char *buf;
 	unsigned char *p;
 	CIPHER **cipher;
-	CIPHER *tmp_c[NUM_CIPHERS];
+	CIPHER *tmp_c[SSL_NUM_CIPHERS];
 	int i,j,num_c,nnum_c;
 
 	buf=s->init_buf;
@@ -330,7 +347,7 @@ SSL *s;
 		 * use to a temp area and then check the server ones
 		 * are put those that are in the session structure again. */
 		cipher= &(s->session->ciphers[0]);
-		memcpy(&(tmp_c[0]),cipher,sizeof(CIPHER *)*NUM_CIPHERS);
+		memcpy(&(tmp_c[0]),cipher,sizeof(CIPHER *)*SSL_NUM_CIPHERS);
 		num_c=s->session->num_ciphers;
 		nnum_c=0;
 		for (i=0; i<(int)s->state_csl; i+=3)
@@ -348,7 +365,7 @@ SSL *s;
 				{
 				s->session->ciphers[nnum_c++]= *cpp;
 				}
-			if (nnum_c == NUM_CIPHERS) break;
+			if (nnum_c == SSL_NUM_CIPHERS) break;
 			}
 		p+=s->state_csl;
 		s->session->num_ciphers=nnum_c;
@@ -375,11 +392,11 @@ SSL *s;
 
 	if ((s->session != NULL) && (s->session->peer != NULL))
 		X509_free(s->session->peer);
-	s->session->peer=s->session->cert->x509;
 
 	/* hmmm, can we have the problem of the other session with this
 	 * cert, free's it before we increment the reference count. */
 	CRYPTO_w_lock(CRYPTO_LOCK_X509);
+	s->session->peer=s->session->cert->x509;
 	s->session->peer->references++;
 	CRYPTO_w_lock(CRYPTO_LOCK_X509);
 
@@ -425,7 +442,7 @@ SSL *s;
 		*(p++)=SSL_MT_CLIENT_HELLO;		/* type */
 		s2n(SSL_CLIENT_VERSION,p);		/* version */
 		n=j=0;
-		for (i=0; i<NUM_CIPHERS; i++)
+		for (i=0; i<SSL_NUM_CIPHERS; i++)
 			{
 			if (ssl_ciphers[i].valid)
 				{
