@@ -49,7 +49,11 @@
 
 #include <stdio.h>
 #include "rc2.h"
+#ifdef NO_MD5
+#include <md5.h>
+#else
 #include "md5.h"
+#endif
 #include "ssl_locl.h"
 #include "ssl_rc2.h"
 
