@@ -46,7 +46,11 @@
  */
 
 #include <stdio.h>
+#ifdef NO_MD5
+#include <md5.h>
+#else
 #include "md5.h"
+#endif
 #include "lhash.h"
 #include "rand.h"
 #include "ssl_locl.h"
@@ -63,7 +67,7 @@ SSL_SESSION *SSL_SESSION_new()
 		return(0);
 		}
 	ss->num_ciphers=0;
-	for (i=0; i<NUM_CIPHERS; i++) ss->ciphers[i]=NULL;
+	for (i=0; i<SSL_NUM_CIPHERS; i++) ss->ciphers[i]=NULL;
 	ss->cipher=NULL;
 	ss->key_arg_length=0;
 	ss->key_arg=NULL;
@@ -75,7 +79,7 @@ SSL_SESSION *SSL_SESSION_new()
 	ss->cert=NULL;
 	ss->peer=NULL;
 	ss->references=1;
-	ss->timeout=60*5; /* minute timeout by default */
+	ss->timeout=60*5; /* 5 minute timeout by default */
 	ss->time=time(NULL);
 	return(ss);
 	}
@@ -88,6 +92,10 @@ int session;
 
 	if ((ss=SSL_SESSION_new()) == NULL) return(0);
 
+	/* If the context has a default timeout, use it */
+	if (s->ctx->session_timeout != 0)
+		ss->timeout=s->ctx->session_timeout;
+
 	if (s->session != NULL)
 		{
 		SSL_SESSION_free(s->session);
@@ -318,7 +326,7 @@ static void timeout(s,p)
 SSL_SESSION *s;
 TIMEOUT_PARAM *p;
 	{
-	if ((p->time == 0) || (p->time < (s->time+s->timeout))) /* timeout */
+	if ((p->time == 0) || (p->time > (s->time+s->timeout))) /* timeout */
 		{
 		lh_delete(p->cache,(char *)s);
 		SSL_SESSION_free(s);
