@@ -46,7 +46,11 @@
  */
 
 #include <stdio.h>
+#ifdef NO_MD5
+#include <md5.h>
+#else
 #include "md5.h"
+#endif
 #include "buffer.h"
 #include "rand.h"
 #include "objects.h"
@@ -196,11 +200,11 @@ SSL *s;
 		case SSL_ST_SEND_REQUEST_CERTIFICATE_C:
 		case SSL_ST_SEND_REQUEST_CERTIFICATE_D:
 			/* don't do a 'request certificate' if we
-			 * don't want to, or we already have one, or
-			 * we once want to ever get one once. */
-			if (!(s->verify_mode & SSL_VERIFY_PEER)
-				|| (s->session->peer != NULL)
-				|| (s->verify_mode & SSL_VERIFY_CLIENT_ONCE))
+			 * don't want to, or we already have one, and
+			 * we only want to do it once. */
+			if (!(s->verify_mode & SSL_VERIFY_PEER) ||
+				((s->session->peer != NULL) &&
+				(s->verify_mode & SSL_VERIFY_CLIENT_ONCE)))
 				{
 				s->state=SSL_ST_SEND_SERVER_FINISHED_A;
 				break;
@@ -228,7 +232,10 @@ SSL *s;
 			s->init_num=0;
 			ERR_clear_error();
 
-			if (SSL_add_session(s->ctx,s->session) &&
+			/* If we want to cache the session-id, and we actual
+			 * get too, and there is a callback, then call it. */
+			if ((s->ctx->session_cache_mode & SSL_SESS_CACHE_SERVER)
+				&& SSL_add_session(s->ctx,s->session) &&
 				(s->ctx->new_session_cb != NULL))
 				{
 				CS_BEGIN;
@@ -242,8 +249,15 @@ SSL *s;
 					}
 				}
 
+			/* flush cache every 32 entries */
+                        if (!((s->ctx->session_cache_mode &
+                                SSL_SESS_CACHE_NO_AUTO_CLEAR)) &&
+				((s->ctx->sess_accept_good & 0x1f) == 0x1f))
+                                SSL_flush_sessions(s->ctx,time(NULL));
+
 			s->ctx->sess_accept_good++;
 			ret=1;
+
 			goto end;
 			BREAK;
 
@@ -294,7 +308,7 @@ SSL *s;
 		c.c2=p[1];
 		c.c3=p[2];
 		cp=(CIPHER *)OBJ_bsearch((char *)&c,(char *)ssl_ciphers,
-			NUM_CIPHERS,sizeof(CIPHER),(int (*)())ssl_cipher_cmp);
+			SSL_NUM_CIPHERS,sizeof(CIPHER),(int (*)())ssl_cipher_cmp);
 		if ((cp == NULL) || (!cp->valid))
 			{
 			ssl_return_error(s);
@@ -459,7 +473,7 @@ SSL *s;
 	if (!s->hit)
 		{
 		CIPHER cc,*cp,**cpp;
-		CIPHER *pref[NUM_CIPHERS],*good[NUM_CIPHERS];
+		CIPHER *pref[SSL_NUM_CIPHERS],*good[SSL_NUM_CIPHERS];
 		int num_ciphers;
 		char *str;
 
@@ -467,7 +481,7 @@ SSL *s;
 
 		/* First up, get a list of valid ciphers */
 		num_ciphers=0;
-		for (i=0; i<NUM_CIPHERS; i++)
+		for (i=0; i<SSL_NUM_CIPHERS; i++)
 			{
 			if (ssl_ciphers[i].valid)
 				pref[num_ciphers++]= &(ssl_ciphers[i]);
@@ -520,7 +534,7 @@ SSL *s;
 				*(cipher++)= *cpp;
 				j++;
 				}
-			if (j == NUM_CIPHERS)
+			if (j == SSL_NUM_CIPHERS)
 				{
 				/* SOMETHING IS WRONG IF WE GET THIS IF THIS
 				 * IS NOT THE LAST ENTRY */
@@ -840,7 +854,12 @@ SSL *s;
 		SSLerr(SSL_F_REQUEST_CERTIFICATE,ERR_R_X509_LIB);
 		goto end;
 		}
-	i=X509_cert_verify(s->ctx->cert,x509,s->verify_callback);
+
+        if (s->ctx->app_verify_callback != NULL)
+                i=s->ctx->app_verify_callback(s->ctx->app_verify_arg,s,x509);
+        else
+                i=X509_cert_verify(s->ctx->cert,x509,s->verify_callback,
+			&s->verify_result);
 
 	if (i)	/* we like the packet, now check the chksum */
 		{
