@@ -1,5 +1,5 @@
 /* ssl/ssl_trc.c */
-/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au)
+/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
  * 
  * This file is part of an SSL implementation written
@@ -70,7 +70,7 @@ void SSL_TRACE ( VAR_PLIST( FILE *, fp ) )
 {
     VAR_BDEFN(args, FILE *, fp);
     char *format;
-#ifdef THREADS
+#if defined(THREADS) && defined(sun)
     struct tm data;
 #endif
     struct  tm	    *tm_time;
@@ -84,7 +84,7 @@ void SSL_TRACE ( VAR_PLIST( FILE *, fp ) )
 	return;
 
     time_now = time ( (time_t *)0 );
-#ifdef THREADS
+#if defined(THREADS) && defined(sun)
     tm_time = localtime_r(&time_now,&data);
 #else
     tm_time = localtime(&time_now);
@@ -124,7 +124,7 @@ void SSL_TRACE ( VAR_PLIST( FILE *, fp ) )
 #undef TRUNCATE
 
 #ifndef TRACEWRITE
-#define TRACEWRITE(X,Y,Z)   Write((X),(Y),(Z))
+#define TRACEWRITE(X,Y,Z)   write((X),(Y),(Z)) /* hmm... */
 #endif
 
 /*
@@ -140,6 +140,7 @@ ssl_ddt_dump(s,len)
 char *s;
 int len;
 {
+#ifndef WIN16
 	int i,j,rows,trunc;
 
         trunc=0;
@@ -178,6 +179,7 @@ int len;
 	if (trunc!=0) 
 	    printf("%04x - <SPACES/NULS>\n",len+trunc);
 #endif
+#endif /* WIN16 */
   return(0);
 }
 
