@@ -44,10 +44,13 @@ foreach $file (@files)
 	open(OUT,">$file.new") || die "unable to open $file.new:$!\n";
 	$found=0;
 
+	print STDERR "$file:";
+
 	while (<IN>)
 		{
-		if (s/SSLeay [^"]*(\"|\s)/SSLeay $ver $time\1/)
+		if (s/SSLeay \d\.\d.\d[^"]*(\"|\s)/SSLeay $ver $time\1/)
 			{
+			print STDERR " Done";
 			$found++;
 			print OUT;
 			while (<IN>) { print OUT; }
@@ -55,6 +58,7 @@ foreach $file (@files)
 			}
 		print OUT;
 		}
+	print STDERR "\n";
 	close(IN);
 	close(OUT);
 	(!$found) && die "unable to update the version number in $file\n";
